@@ -10,15 +10,14 @@ use Moo::Role;
 =head1 NAME
 
 Net::JBoss - Bindings for JBoss Management API
-             Tested on JBoss EAP v6.3.x
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 =head1 SYNOPSIS
@@ -29,7 +28,10 @@ our $VERSION = '0.02';
             username                => 'admin',
             password                => 'password',
             server                  => 'jboss1.example.com',
-            port                    => 9990, #optional
+            port                    => 9443,                    #optional, default is 9990
+            ssl                     => 'on',                    #optional, default is 'off'
+            ssl_verify              => 'yes',                   #optional, default is 'no'
+            realm                   => 'ManagementRealmHTTPS'   #optional, default is 'ManagementRealm'
  );
 
  my $jboss              = Net::JBoss::Management->new(%con);
@@ -37,12 +39,25 @@ our $VERSION = '0.02';
  my $state              = $jboss->get_state();
  my $jvm_usage          = $jboss->get_jvm_usage();
  my $runtime_stats      = $jboss->get_runtime_stats();
+ my $deploy_info        = $jboss->get_deployment_info();
+ my $app_runtime_stats  = $jboss->get_app_runtime_stats('hawtio.war');
  my $runtime_details    = $jboss->get_runtime_details();
- my $server_env         = $jboss->get_server_env();
- my $datasources        = $jboss->get_datasources();
  my $app_status         = $jboss->get_app_status('hawtio.war');
  my $active_session     = $jboss->get_active_sessions('hawtio.war');
+ my $server_env         = $jboss->get_server_env();
+ my $datasources        = $jboss->get_datasources();
+ my $test               = $jboss->test_con_pool('ExampleDS');
  my $pool_stats         = $jboss->get_ds_pool_stats('java:jboss/datasources/jboss_Pool');
+ my $enable_pool_stats  = $jboss->get_ds_pool_stats('java:jboss/datasources/jboss_Pool', 'true');
+ my $disable_pool_stats = $jboss->get_ds_pool_stats('java:jboss/datasources/jboss_Pool', 'false');
+ my $min_pool_size      = $jboss->set_ds_pool_size('min', 'java:jboss/datasources/jboss_Pool', 20);
+ my $max_pool_size      = $jboss->set_ds_pool_size('max', 'java:jboss/datasources/jboss_Pool', 50);
+ my $jndi               = $jboss->get_jndi();
+ my $loglevel           = $jboss->get_log_level('CONSOLE');
+ my $loglevel           = $jboss->set_log_level('CONSOLE', 'ERROR');
+ my $reload             = $jboss->reload();
+ my $shutdown           = $jboss->shutdown();
+ my $restart            = $jboss->restart();
 
 =head1 Attributes
 
@@ -63,6 +78,8 @@ our $VERSION = '0.02';
  log            = (rwp) store log from log4perl
  http_post      = (rwp) if true, use http post method instead of get
  post_json      = (rwp) set json content to be post
+ ssl            = (ro) if 'on', use https (default is 'off')
+ ssl_verify     = (ro) disable host verification, yes/no (default is 'no')
 
 =cut
 
@@ -85,12 +102,35 @@ has 'port'          => ( is => 'ro', default => 9990,
 
 has 'log_severity'  => ( is => 'ro', 
                         isa => sub { croak "log severity value not valid\n" 
-                                        unless $_[0] =~ /(ERROR|OFF|FATAL|INFO|DEBUG|TRACE|ALL|WARN)/;
+                                        unless $_[0] =~ /\b(ERROR|OFF|FATAL|INFO|DEBUG|TRACE|ALL|WARN)\b/;
                                     }, 
                         default => 'INFO'
 );
 
 has 'realm'         => ( is => 'ro', default => 'ManagementRealm' );
+has 'ssl'           => ( is => 'ro', default => 'off', 
+                         isa => 
+                            sub {
+                                croak "valid ssl value is on or off"
+                                    unless $_[0] =~ /\b(on|off)\b/;
+                            }
+                        );
+has 'ssl_verify'    => ( is => 'ro', 
+                         isa    => sub { 
+                                        my $ssl_verify  = $_[0];
+                                        $ssl_verify     = lc ($ssl_verify);
+                                        
+                                        if ($ssl_verify eq 'yes') {
+                                            $ENV{'PERL_LWP_SSL_VERIFY_HOSTNAME'} = 1;
+                                        }
+                                        elsif ($ssl_verify eq 'no') {
+                                            $ENV{'PERL_LWP_SSL_VERIFY_HOSTNAME'} = 0;
+                                        }
+                                        else {
+                                            croak "ssl_verify valid argument is yes/no";
+                                        }
+                                    },    
+                         default => sub { $ENV{'PERL_LWP_SSL_VERIFY_HOSTNAME'} = 0; return 'no'; } );
 
 =head1 SUBROUTINES/METHODS
 
@@ -161,8 +201,13 @@ sub base_url {
         $url =  $self->server . ":" . $self->port;
     }
     
-    # handle only http
-    $url = "http://" . $url; 
+    # http or https
+    if ($self->ssl eq 'off') {
+        $url = "http://" . $url;
+    }
+    else {
+        $url = "https://" . $url;
+    } 
   
     $self->log->debug($url);
     return $url;
