@@ -13,11 +13,11 @@ Net::JBoss::Management - Bindings for JBoss Management API
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 =head1 SYNOPSIS
@@ -28,7 +28,10 @@ use Net::JBoss::Management;
             username                => 'admin',
             password                => 'password',
             server                  => 'jboss1.example.com',
-            port                    => 9990, #optional
+            port                    => 9443,                    #optional, default is 9990
+            ssl                     => 'on',                    #optional, default is 'off'
+            ssl_verify              => 'yes',                   #optional, default is 'no'
+            realm                   => 'ManagementRealmHTTPS'   #optional, default is 'ManagementRealm'
  );
  
  my $jboss              = Net::JBoss::Management->new(%con);
